Contributing to fmt
===================

All C++ code must adhere to `Google C++ Style Guide
<https://google.github.io/styleguide/cppguide.html>`_ with the following
exceptions:

* Exceptions are permitted
* snake_case should be used instead of UpperCamelCase for function names

Thanks for contributing!
